pub enum DeliveryFailureKind {
InvalidReference(InvalidReference),
Undeliverable(UndeliverableReason),
Expired(ExpiredDelivery),
}Expand description
The kind of delivery failure.
Variants
InvalidReference(InvalidReference)
The destination reference does not denote a valid recipient.
Undeliverable(UndeliverableReason)
The message could not be delivered for transport or receiver-lifecycle reasons.
Expired(ExpiredDelivery)
The message exceeded its TTL.
Implementations
Sourceimpl DeliveryFailureKind
impl DeliveryFailureKind
Sourcepub fn is_invalid_reference(&self) -> bool
pub fn is_invalid_reference(&self) -> bool
Returns true if this is a DeliveryFailureKind::InvalidReference, otherwise false
Sourcepub fn as_invalid_reference_mut(&mut self) -> Option<&mut InvalidReference>
pub fn as_invalid_reference_mut(&mut self) -> Option<&mut InvalidReference>
Optionally returns mutable references to the inner fields if this is a DeliveryFailureKind::InvalidReference, otherwise None
Sourcepub fn as_invalid_reference(&self) -> Option<&InvalidReference>
pub fn as_invalid_reference(&self) -> Option<&InvalidReference>
Optionally returns references to the inner fields if this is a DeliveryFailureKind::InvalidReference, otherwise None
Sourcepub fn into_invalid_reference(self) -> Result<InvalidReference, Self>
pub fn into_invalid_reference(self) -> Result<InvalidReference, Self>
Returns the inner fields if this is a DeliveryFailureKind::InvalidReference, otherwise returns back the enum in the Err case of the result
Sourcepub fn is_undeliverable(&self) -> bool
pub fn is_undeliverable(&self) -> bool
Returns true if this is a DeliveryFailureKind::Undeliverable, otherwise false
Sourcepub fn as_undeliverable_mut(&mut self) -> Option<&mut UndeliverableReason>
pub fn as_undeliverable_mut(&mut self) -> Option<&mut UndeliverableReason>
Optionally returns mutable references to the inner fields if this is a DeliveryFailureKind::Undeliverable, otherwise None
Sourcepub fn as_undeliverable(&self) -> Option<&UndeliverableReason>
pub fn as_undeliverable(&self) -> Option<&UndeliverableReason>
Optionally returns references to the inner fields if this is a DeliveryFailureKind::Undeliverable, otherwise None
Sourcepub fn into_undeliverable(self) -> Result<UndeliverableReason, Self>
pub fn into_undeliverable(self) -> Result<UndeliverableReason, Self>
Returns the inner fields if this is a DeliveryFailureKind::Undeliverable, otherwise returns back the enum in the Err case of the result
Sourcepub fn is_expired(&self) -> bool
pub fn is_expired(&self) -> bool
Returns true if this is a DeliveryFailureKind::Expired, otherwise false
Sourcepub fn as_expired_mut(&mut self) -> Option<&mut ExpiredDelivery>
pub fn as_expired_mut(&mut self) -> Option<&mut ExpiredDelivery>
Optionally returns mutable references to the inner fields if this is a DeliveryFailureKind::Expired, otherwise None
Sourcepub fn as_expired(&self) -> Option<&ExpiredDelivery>
pub fn as_expired(&self) -> Option<&ExpiredDelivery>
Optionally returns references to the inner fields if this is a DeliveryFailureKind::Expired, otherwise None
Sourcepub fn into_expired(self) -> Result<ExpiredDelivery, Self>
pub fn into_expired(self) -> Result<ExpiredDelivery, Self>
Returns the inner fields if this is a DeliveryFailureKind::Expired, otherwise returns back the enum in the Err case of the result