pub enum TransportFailureReason {
ChannelClosed {
addr: ChannelAddr,
},
AckTimedOut {
addr: ChannelAddr,
},
DialFailed {
addr: ChannelAddr,
error: String,
},
NoRoute,
OversizedFrame {
len: usize,
max: usize,
},
LinkUnavailable(String),
ForwarderUnavailable,
}Expand description
Why transport failed.
Variants
ChannelClosed
The channel closed.
Fields

addr: ChannelAddrThe channel address.
AckTimedOut
Delivery acknowledgement timed out.
Fields

addr: ChannelAddrThe channel address.
DialFailed
Dialing the destination failed.
NoRoute
The router has no route and is not authoritative for destination existence.
OversizedFrame
The serialized frame exceeded the configured channel frame limit.
A weak reference in the delivery path could not be upgraded.
The forwarder is unavailable.