pub enum Undeliverable<M: Message> {
Returned(M),
Report(DeliveryFailureReport),
}Expand description
An undeliverable M-typed message.
Variants
Returned(M)
The message was returned intact.
Report(DeliveryFailureReport)
Delivery failed, but the original payload is unavailable.
Implementations
Sourceimpl<M: Message> Undeliverable<M>
impl<M: Message> Undeliverable<M>
Sourcepub fn is_returned(&self) -> bool
pub fn is_returned(&self) -> bool
Returns true if this is a Undeliverable::Returned, otherwise false
Sourcepub fn as_returned_mut(&mut self) -> Option<&mut M>
pub fn as_returned_mut(&mut self) -> Option<&mut M>
Optionally returns mutable references to the inner fields if this is a Undeliverable::Returned, otherwise None
Sourcepub fn as_returned(&self) -> Option<&M>
pub fn as_returned(&self) -> Option<&M>
Optionally returns references to the inner fields if this is a Undeliverable::Returned, otherwise None
Sourcepub fn into_returned(self) -> Result<M, Self>
pub fn into_returned(self) -> Result<M, Self>
Returns the inner fields if this is a Undeliverable::Returned, otherwise returns back the enum in the Err case of the result
Sourcepub fn is_report(&self) -> bool
pub fn is_report(&self) -> bool
Returns true if this is a Undeliverable::Report, otherwise false
Sourcepub fn as_report_mut(&mut self) -> Option<&mut DeliveryFailureReport>
pub fn as_report_mut(&mut self) -> Option<&mut DeliveryFailureReport>
Optionally returns mutable references to the inner fields if this is a Undeliverable::Report, otherwise None
Sourcepub fn as_report(&self) -> Option<&DeliveryFailureReport>
pub fn as_report(&self) -> Option<&DeliveryFailureReport>
Optionally returns references to the inner fields if this is a Undeliverable::Report, otherwise None
Sourcepub fn into_report(self) -> Result<DeliveryFailureReport, Self>
pub fn into_report(self) -> Result<DeliveryFailureReport, Self>
Returns the inner fields if this is a Undeliverable::Report, otherwise returns back the enum in the Err case of the result
Sourceimpl<M: Message> Undeliverable<M>
impl<M: Message> Undeliverable<M>
Sourcepub fn message(message: M) -> Self
pub fn message(message: M) -> Self
Construct an undeliverable message that preserves the original payload.
Sourcepub fn as_message(&self) -> Option<&M>
pub fn as_message(&self) -> Option<&M>
Borrow the returned payload, if the payload was returned.
Sourcepub fn as_message_mut(&mut self) -> Option<&mut M>
pub fn as_message_mut(&mut self) -> Option<&mut M>
Mutably borrow the returned payload, if the payload was returned.
Sourcepub fn into_message(self) -> Result<M, Self>
pub fn into_message(self) -> Result<M, Self>
Consume this undeliverable notification and return its payload, if the payload was returned.
Sourcepub fn report(report: DeliveryFailureReport) -> Self
pub fn report(report: DeliveryFailureReport) -> Self
Construct an undeliverable message that carries only delivery-failure metadata.
Sourceimpl Undeliverable<MessageEnvelope>
impl Undeliverable<MessageEnvelope>
Sourcepub fn root_delivery_failure(&self) -> Option<&DeliveryFailure>
pub fn root_delivery_failure(&self) -> Option<&DeliveryFailure>
Get the root structured delivery failure for this undeliverable notification.
Sourcepub fn into_error(self) -> UndeliverableMessageError
pub fn into_error(self) -> UndeliverableMessageError
Convert this undeliverable notification into the corresponding error.