pub enum UndeliverableMessageError {
DeliveryFailure {
envelope: MessageEnvelope,
},
ReturnFailure {
envelope: MessageEnvelope,
},
Lost {
lost: LostMessage,
},
}Expand description
Errors that occur during message delivery and return.
Variants
DeliveryFailure
Delivery of a message to its destination failed.
Fields

envelope: MessageEnvelopeThe undelivered message.
ReturnFailure
Delivery of an undeliverable message back to its sender failed.
Fields

envelope: MessageEnvelopeThe undelivered message.
Lost
A message was lost before it could be returned.
Fields

lost: LostMessageThe lost-message metadata.