pub enum UndeliverableReason {
Transport(TransportFailure),
PortGone(PortGone),
}Expand description
A non-invalid-reference delivery failure.
Variants
Transport(TransportFailure)
Delivery failed while carrying the message.
PortGone(PortGone)
The destination port’s ordinary recipient is gone.
Implementations
Sourceimpl UndeliverableReason
impl UndeliverableReason
Sourcepub fn is_transport(&self) -> bool
pub fn is_transport(&self) -> bool
Returns true if this is a UndeliverableReason::Transport, otherwise false
Sourcepub fn as_transport_mut(&mut self) -> Option<&mut TransportFailure>
pub fn as_transport_mut(&mut self) -> Option<&mut TransportFailure>
Optionally returns mutable references to the inner fields if this is a UndeliverableReason::Transport, otherwise None
Sourcepub fn as_transport(&self) -> Option<&TransportFailure>
pub fn as_transport(&self) -> Option<&TransportFailure>
Optionally returns references to the inner fields if this is a UndeliverableReason::Transport, otherwise None
Sourcepub fn into_transport(self) -> Result<TransportFailure, Self>
pub fn into_transport(self) -> Result<TransportFailure, Self>
Returns the inner fields if this is a UndeliverableReason::Transport, otherwise returns back the enum in the Err case of the result
Sourcepub fn is_port_gone(&self) -> bool
pub fn is_port_gone(&self) -> bool
Returns true if this is a UndeliverableReason::PortGone, otherwise false
Sourcepub fn as_port_gone_mut(&mut self) -> Option<&mut PortGone>
pub fn as_port_gone_mut(&mut self) -> Option<&mut PortGone>
Optionally returns mutable references to the inner fields if this is a UndeliverableReason::PortGone, otherwise None
Sourcepub fn as_port_gone(&self) -> Option<&PortGone>
pub fn as_port_gone(&self) -> Option<&PortGone>
Optionally returns references to the inner fields if this is a UndeliverableReason::PortGone, otherwise None
Sourcepub fn into_port_gone(self) -> Result<PortGone, Self>
pub fn into_port_gone(self) -> Result<PortGone, Self>
Returns the inner fields if this is a UndeliverableReason::PortGone, otherwise returns back the enum in the Err case of the result