pub enum Undeliverable<M: Message> {
Message(M),
Lost(LostMessage),
}Expand description
An undeliverable M-typed message.
Variants
Message(M)
The message was returned intact.
Lost(LostMessage)
The message was lost before it could be returned.
Implementations
Sourceimpl<M: Message> Undeliverable<M>
impl<M: Message> Undeliverable<M>
Sourcepub fn is_message(&self) -> bool
pub fn is_message(&self) -> bool
Returns true if this is a Undeliverable::Message, otherwise false
Sourcepub fn as_message_mut(&mut self) -> Option<&mut M>
pub fn as_message_mut(&mut self) -> Option<&mut M>
Optionally returns mutable references to the inner fields if this is a Undeliverable::Message, otherwise None
Sourcepub fn as_message(&self) -> Option<&M>
pub fn as_message(&self) -> Option<&M>
Optionally returns references to the inner fields if this is a Undeliverable::Message, otherwise None
Sourcepub fn into_message(self) -> Result<M, Self>
pub fn into_message(self) -> Result<M, Self>
Returns the inner fields if this is a Undeliverable::Message, otherwise returns back the enum in the Err case of the result
Sourcepub fn as_lost_mut(&mut self) -> Option<&mut LostMessage>
pub fn as_lost_mut(&mut self) -> Option<&mut LostMessage>
Optionally returns mutable references to the inner fields if this is a Undeliverable::Lost, otherwise None
Sourcepub fn as_lost(&self) -> Option<&LostMessage>
pub fn as_lost(&self) -> Option<&LostMessage>
Optionally returns references to the inner fields if this is a Undeliverable::Lost, otherwise None
Sourcepub fn into_lost(self) -> Result<LostMessage, Self>
pub fn into_lost(self) -> Result<LostMessage, Self>
Returns the inner fields if this is a Undeliverable::Lost, otherwise returns back the enum in the Err case of the result
Sourceimpl<M: Message> Undeliverable<M>
impl<M: Message> Undeliverable<M>
Sourcepub fn message(message: M) -> Self
pub fn message(message: M) -> Self
Construct an undeliverable message that preserves the original payload.
Sourcepub fn lost(message: LostMessage) -> Self
pub fn lost(message: LostMessage) -> Self
Construct an undeliverable message that carries only lost-message metadata.